@@ -10,8 +10,6 @@ password ="Administrator"
 server="85.214.60.83"
 port="8080"
 
-
-
 cube_upload_param={}
 # conn_det=None
 chg_log_from_date = "2023-01-14"
@@ -43,22 +41,22 @@ change_log_report={"chg_log_rep_proj_id":chg_log_rep_proj_id
                    , "migration_folder_id": migration_folder_id
                    , "chg_log_obj_prompt_id": chg_log_obj_prompt_id
                    }
-
+"""
 change_query={"chg_log_from_date":chg_log_from_date
               ,"chg_log_to_date":chg_log_to_date
               ,"short_cut_proj_id":short_cut_proj_id
               ,"short_cut_folder_id": short_cut_folder_id
               ,"mtdi_id":None
               ,"cube_name":"TestCube"}
-
+"""
 
 conn=mig.login(base_url=base_url,username=username,password=password,project_id=chg_log_rep_proj_id)
-""" 
-res=mig_rep.chk_chg_log_cols(conn=conn,report_id="454B29DF4872B9C74785A5A0A1A5FFB0")
-print(res)
+
+#res=mig_rep.chk_chg_log_cols(conn=conn,report_id="454B29DF4872B9C74785A5A0A1A5FFB0")
+#print(res)
 
 #pass over the parameters
-mig_rep.set_md_rep_params(conn=conn,change_query=change_query,change_log_report=change_log_report)
+mig_rep.set_md_rep_params(conn=conn,change_log_report=change_log_report)
 #get the changed objetcs from change logs
 #for a project and timeframe
 ch_df=mig_rep.get_mig_obj_logs(conn=conn,proect_id=short_cut_proj_id,from_date=chg_log_from_date,
@@ -71,13 +69,10 @@ ch_df=mig_rep.get_mig_obj_logs(conn=conn,proect_id=short_cut_proj_id,from_date=c
 #create short cuts for change logs at level of user & object
 
 short_cut_df= mig_rep.bld_change_log_shortcut_df(conn=conn,change_log_df=ch_df)
-df_key_cols_d={"object_id":"OBJECT_ID",
-                           "object_type":"OBJECT_TYPE",
-                           "object_name":"NEW_OBJECT_NAME",
-                           "object_desc":"NEW_OBJECT_DESC"}
-mig_short_cut.run_short_cut_build(conn=conn, project_id=change_query["short_cut_proj_id"],
-                                  short_cut_df=short_cut_df,folder_id=change_query["short_cut_folder_id"],df_key_cols_d=df_key_cols_d)
-"""
+
+mig_short_cut.run_short_cut_build(conn=conn, project_id=short_cut_proj_id,
+                                  short_cut_df=short_cut_df,folder_id=short_cut_folder_id)
+
 #mig_short_cut.run_short_cut_build(conn=conn, project_id=change_query["short_cut_proj_id"],
 #                                  short_cut_df=short_cut_df,folder_id=change_query["short_cut_folder_id"],short_cut_col=short_cut_col)
 
