@@ -16,6 +16,7 @@ from typing import Optional
 from mstr_robotics.helper import str_func
 from mstr_robotics.logger import logger
 from mstr_robotics.lu_data import lu_mstr_md
+import uuid
 
 
 
@@ -98,8 +99,12 @@ class mstr_global:
 
     @log(err_name="Failed to rename object")
     def _rename_object(self, conn,project_id,object_id,object_type, new_name, desc_str):
+
         short_cut_obj = object.Object(connection=conn, type=object_type, id=object_id)
-        short_cut_obj.alter(name=str(new_name), description=str(desc_str))
+        try:
+            short_cut_obj.alter(name=str(new_name), description=str(desc_str))
+        except:
+            short_cut_obj.alter(name=str(new_name + uuid.uuid1().hex), description=str(desc_str))
         return
 
     @log(err_name="Didn't find object or could parse it")
